@@ -1,9 +1,9 @@
 ///////////////////////////////////////////////////////////////////////////////
 //                                                                           //
-//                     LibXL C headers version 5.0.1                         //
+//                     LibXL C headers version 5.1.0                         //
 //                  for multi-byte character set (char)                      //
 //                                                                           //
-//                 Copyright (c) 2008 - 2025 XLware s.r.o.                   //
+//                 Copyright (c) 2008 - 2026 XLware s.r.o.                   //
 //                                                                           //
 //   THIS FILE AND THE SOFTWARE CONTAINED HEREIN IS PROVIDED 'AS IS' AND     //
 //                COMES WITH NO WARRANTIES OF ANY KIND.                      //
@@ -286,7 +286,10 @@ extern "C"
     XLAPI           int XLAPIENTRY xlSheetFormControlSizeA(SheetHandle handle);
     XLAPI FormControlHandle XLAPIENTRY xlSheetFormControlA(SheetHandle handle, int index);
 
-    XLAPI ConditionalFormattingHandle XLAPIENTRY xlSheetAddConditionalFormattingA(SheetHandle handle);
+    XLAPI ConditionalFormattingHandle XLAPIENTRY xlSheetAddConditionalFormattingA(SheetHandle handle, int rowFirst, int rowLast, int colFirst, int colLast);
+    XLAPI ConditionalFormattingHandle XLAPIENTRY xlSheetConditionalFormattingA(SheetHandle handle, int index);
+    XLAPI                         int XLAPIENTRY xlSheetRemoveConditionalFormattingA(SheetHandle handle, int index);
+    XLAPI                         int XLAPIENTRY xlSheetConditionalFormattingSizeA(SheetHandle handle);
 
     XLAPI int XLAPIENTRY xlSheetGetActiveCellA(SheetHandle handle, int* row, int* col);
     XLAPI void XLAPIENTRY xlSheetSetActiveCellA(SheetHandle handle, int row, int col);
