@@ -1,9 +1,9 @@
 ///////////////////////////////////////////////////////////////////////////////
 //                                                                           //
-//                     LibXL C headers version 5.0.1                         //
+//                     LibXL C headers version 5.1.0                         //
 //                  for unicode character set (wchar_t)                      //
 //                                                                           //
-//                 Copyright (c) 2008 - 2025 XLware s.r.o.                   //
+//                 Copyright (c) 2008 - 2026 XLware s.r.o.                   //
 //                                                                           //
 //   THIS FILE AND THE SOFTWARE CONTAINED HEREIN IS PROVIDED 'AS IS' AND     //
 //                COMES WITH NO WARRANTIES OF ANY KIND.                      //
@@ -287,7 +287,10 @@ extern "C"
     XLAPI           int XLAPIENTRY xlSheetFormControlSizeW(SheetHandle handle);
     XLAPI FormControlHandle XLAPIENTRY xlSheetFormControlW(SheetHandle handle, int index);
 
-    XLAPI ConditionalFormattingHandle XLAPIENTRY xlSheetAddConditionalFormattingW(SheetHandle handle);
+    XLAPI ConditionalFormattingHandle XLAPIENTRY xlSheetAddConditionalFormattingW(SheetHandle handle, int rowFirst, int rowLast, int colFirst, int colLast);
+    XLAPI ConditionalFormattingHandle XLAPIENTRY xlSheetConditionalFormattingW(SheetHandle handle, int index);
+    XLAPI                         int XLAPIENTRY xlSheetRemoveConditionalFormattingW(SheetHandle handle, int index);
+    XLAPI                         int XLAPIENTRY xlSheetConditionalFormattingSizeW(SheetHandle handle);
 
     XLAPI int XLAPIENTRY xlSheetGetActiveCellW(SheetHandle handle, int* row, int* col);
     XLAPI void XLAPIENTRY xlSheetSetActiveCellW(SheetHandle handle, int row, int col);
