@@ -1,8 +1,8 @@
 ///////////////////////////////////////////////////////////////////////////////
 //                                                                           //
-//                     LibXL C headers version 5.0.0                         //
+//                     LibXL C headers version 5.1.0                         //
 //                                                                           //
-//                 Copyright (c) 2008 - 2025 XLware s.r.o.                   //
+//                 Copyright (c) 2008 - 2026 XLware s.r.o.                   //
 //                                                                           //
 //   THIS FILE AND THE SOFTWARE CONTAINED HEREIN IS PROVIDED 'AS IS' AND     //
 //                COMES WITH NO WARRANTIES OF ANY KIND.                      //
@@ -14,7 +14,7 @@
 #ifndef LIBXL_C_H
 #define LIBXL_C_H
 
-#define LIBXL_VERSION 0x05000000
+#define LIBXL_VERSION 0x05010000
 
 #ifdef _UNICODE
 
@@ -41,9 +41,11 @@
     #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileW
     #define xlBookLoadWithoutEmptyCells xlBookLoadWithoutEmptyCellsW
     #define xlBookLoadInfo xlBookLoadInfoW
+    #define xlBookLoadInfoRaw xlBookLoadInfoRawW
     #define xlBookLoadRaw xlBookLoadRawW
     #define xlBookLoadRawPartially xlBookLoadRawPartiallyW
     #define xlBookSaveRaw xlBookSaveRawW
+    #define xlBookSetPassword xlBookSetPasswordW
     #define xlBookAddSheet xlBookAddSheetW
     #define xlBookInsertSheet xlBookInsertSheetW
     #define xlBookGetSheet xlBookGetSheetW
@@ -63,6 +65,8 @@
     #define xlBookFont xlBookFontW
     #define xlBookFontSize xlBookFontSizeW
     #define xlBookAddConditionalFormat xlBookAddConditionalFormatW
+    #define xlBookConditionalFormat xlBookConditionalFormatW
+    #define xlBookConditionalFormatSize xlBookConditionalFormatSizeW
     #define xlBookDatePack xlBookDatePackW
     #define xlBookDateUnpack xlBookDateUnpackW
     #define xlBookColorPack xlBookColorPackW
@@ -95,7 +99,11 @@
     #define xlBookRemoveVBA xlBookRemoveVBAW
     #define xlBookRemovePrinterSettings xlBookRemovePrinterSettingsW
     #define xlBookRemoveAllPhonetics xlBookRemoveAllPhoneticsW
+    #define xlBookDpiAwareness xlBookDpiAwarenessW
+    #define xlBookSetDpiAwareness xlBookSetDpiAwarenessW
+    #define xlBookClear xlBookClearW
     #define xlBookErrorMessage xlBookErrorMessageW
+    #define xlBookErrorCode xlBookErrorCodeW
     #define xlBookRelease xlBookReleaseW
 
     #define xlSheetCellType xlSheetCellTypeW
@@ -275,6 +283,9 @@
     #define xlSheetFormControlSize xlSheetFormControlSizeW
     #define xlSheetFormControl xlSheetFormControlW
     #define xlSheetAddConditionalFormatting xlSheetAddConditionalFormattingW
+    #define xlSheetConditionalFormatting xlSheetConditionalFormattingW
+    #define xlSheetRemoveConditionalFormatting xlSheetConditionalFormattingW
+    #define xlSheetConditionalFormattingSize xlSheetConditionalFormattingW
     #define xlSheetGetActiveCell xlSheetGetActiveCellW
     #define xlSheetSetActiveCell xlSheetSetActiveCellW
     #define xlSheetSelectionRange xlSheetSelectionRangeW
@@ -532,9 +543,11 @@
     #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileA
     #define xlBookLoadWithoutEmptyCells xlBookLoadWithoutEmptyCellsA
     #define xlBookLoadInfo xlBookLoadInfoA
+    #define xlBookLoadInfoRaw xlBookLoadInfoRawA
     #define xlBookLoadRaw xlBookLoadRawA
     #define xlBookLoadRawPartially xlBookLoadRawPartiallyA
     #define xlBookSaveRaw xlBookSaveRawA
+    #define xlBookSetPassword xlBookSetPasswordA
     #define xlBookAddSheet xlBookAddSheetA
     #define xlBookInsertSheet xlBookInsertSheetA
     #define xlBookGetSheet xlBookGetSheetA
@@ -554,6 +567,8 @@
     #define xlBookFont xlBookFontA
     #define xlBookFontSize xlBookFontSizeA
     #define xlBookAddConditionalFormat xlBookAddConditionalFormatA
+    #define xlBookConditionalFormat xlBookConditionalFormatA
+    #define xlBookConditionalFormatSize xlBookConditionalFormatSizeA
     #define xlBookDatePack xlBookDatePackA
     #define xlBookDateUnpack xlBookDateUnpackA
     #define xlBookColorPack xlBookColorPackA
@@ -586,7 +601,11 @@
     #define xlBookRemoveVBA xlBookRemoveVBAA
     #define xlBookRemovePrinterSettings xlBookRemovePrinterSettingsA
     #define xlBookRemoveAllPhonetics xlBookRemoveAllPhoneticsA
+    #define xlBookDpiAwareness xlBookDpiAwarenessA
+    #define xlBookSetDpiAwareness xlBookSetDpiAwarenessA
+    #define xlBookClear xlBookClearA
     #define xlBookErrorMessage xlBookErrorMessageA
+    #define xlBookErrorCode xlBookErrorCodeA
     #define xlBookRelease xlBookReleaseA
 
     #define xlSheetCellType xlSheetCellTypeA
@@ -766,6 +785,9 @@
     #define xlSheetFormControlSize xlSheetFormControlSizeA
     #define xlSheetFormControl xlSheetFormControlA
     #define xlSheetAddConditionalFormatting xlSheetAddConditionalFormattingA
+    #define xlSheetConditionalFormatting xlSheetConditionalFormattingA
+    #define xlSheetRemoveConditionalFormatting xlSheetConditionalFormattingA
+    #define xlSheetConditionalFormattingSize xlSheetConditionalFormattingA
     #define xlSheetGetActiveCell xlSheetGetActiveCellA
     #define xlSheetSetActiveCell xlSheetSetActiveCellA
     #define xlSheetSelectionRange xlSheetSelectionRangeA
